@@ -6,6 +6,7 @@
 #
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 #
+import abc
 from typing import Optional, Mapping, Any
 
 from init_helpers.custom_json import Jsonable
@@ -13,21 +14,23 @@ from init_helpers.custom_json import Jsonable
 from http_tools import AbmServiceConnector
 
 
-class AbmServiceAuthedConnector:
+class AbmServiceAuthedConnector(abc.ABC):
     Config = AbmServiceConnector.Config
     Context = AbmServiceConnector.Context
 
     def __init__(self, config: Config, context: Context) -> None:
         self._connector = AbmServiceConnector(config, context)
 
+    @abc.abstractmethod
     async def get(self,
                   path: str,
                   url_query: Optional[Mapping[str, Any]] = None,
                   headers: Optional[Mapping[str, str]] = None,
                   token: str = None,
                   timeout_sec: Optional[float] = None) -> Any:
-        raise NotImplementedError
+        pass
 
+    @abc.abstractmethod
     async def post(self,
                    path: str,
                    payload: bytes | Jsonable,
@@ -35,4 +38,4 @@ class AbmServiceAuthedConnector:
                    headers: Optional[Mapping[str, str]] = None,
                    token: str = None,
                    timeout_sec: Optional[float] = None) -> Any:
-        raise NotImplementedError
+        pass
